==> scilab-2.1.1.tar.gz: scilab-2.1.1/routines/xsci/help/help-text7.h <==
"  %K   - Jacobi's complete elliptic integral ",
"  %asn   - elliptic integral ",
"  %sn   - Jacobi 's elliptic function ",
"  Signal   - Signal manual description ",
"  analpf   - create analog low-pass filter  ",
"  buttmag   -  response of Butterworth filter ",
"  casc   -  cascade realization of filter from coefficients ",
"  cheb1mag   -  response of Chebyshev type 1 filter ",
"  Cheb2mag   - response of type 2 Chebyshev filter ",
"  chepol   - Chebychev polynomial ",
"  convol   - convolution (overlap add method) ",
"  corr   - correlation, covariance ",
"  cspect   - spectral estimation (periodogram method) ",
"  czt   - chirp z-transform algorithm ",
"  dft   - discrete fourier transform ",
"  ell1mag   - magnitude of elliptic filter ",
"  eqfir   - minimax approximation of FIR filter ",
"  eqiir   - Design of iir filters ",
"  faurre   - filter ",
"  ffilt   - coefficients of FIR low-pass ",
"  fft   - fast fourier transform. ",
"  filter   - modelling filter ",
"  find_freq   - parameter compatibility for elliptic filter design ",
"  findm   - for elliptic filter design ",
"  frmag   - magnitude of FIR and IIR filters ",
"  fsfirlin   - design of FIR, linear phase filters ",
"  fwiir   - IIR filters in cascade realization ",
"  group   - group delay for digital filter ",
"  hank   - hankel matrix ",
"  hilb   - Hilbert transform ",
"  iir   - iir digital filter ",
"  iirgroup   - group delay Lp IIR filter optimization ",
"  iirlp   - Lp IIR filter optimization ",
"  intdec   - Changes  sampling rate of a signal ",
"  jmat   - row or column block permutation ",
"  kalm   - Kalman update ",
"  lattn   - recursive solution of normal equations ",
"  lattp   - lattp ",
"  lev   - Yule-Walker equations (Levinson's algorithm) ",
"  levin   - Toeplitz system solver ",
"  lgfft   - utility for fft ",
"  lindquist   - Lindquist's algorithm ",
"  mese   - maximum entropy spectral estimation ",
"  mfft   - multi-dimensional fft ",
"  phc   - from the hankel matrix to state-space model ",
"  pspect   - cross-spectral estimate between 2 series ",
"  remez   - Remez's algorithm ",
"  remezb   - Minimax approximation of magnitude response ",
"  rpem   - RPEM estimation ",
"  sinc   -  samples of sinc function ",
"  sincd   - sinc function ",
"  srfaur   - square-root algorithm ",
"  srkf   - square root Kalman filter ",
"  sskf   - steady-state Kalman filter ",
"  system   - observation update ",
"  trans   - low-pass to other filter transform ",
"  wfir   - linear-phase FIR filters ",
"  wiener   -  Wiener estimate ",
"  wigner   - 'time-frequency' wigner spectrum ",
"  window   - symmetric window ",
"  zpbutt   - Butterworth analog filter ",
"  zpch1   - Chebyshev analog filter ",
"  zpch2   - Chebyshev analog filter ",
"  zpell   - lowpass elliptic filter ",

==> scilab_2.2.orig.tar.gz: scilab-2.2.orig/routines/xsci/help/help-text7.h <==
"  %K   - Jacobi's complete elliptic integral ",
"  %asn   - elliptic integral ",
"  %sn   - Jacobi 's elliptic function ",
"  Signal   - Signal manual description ",
"  analpf   - create analog low-pass filter  ",
"  buttmag   -  response of Butterworth filter ",
"  casc   -  cascade realization of filter from coefficients ",
"  cheb1mag   -  response of Chebyshev type 1 filter ",
"  Cheb2mag   - response of type 2 Chebyshev filter ",
"  chepol   - Chebychev polynomial ",
"  convol   - convolution ",
"  corr   - correlation, covariance ",
"  cspect   - spectral estimation (periodogram method) ",
"  czt   - chirp z-transform algorithm ",
"  dft   - discrete fourier transform ",
"  ell1mag   - magnitude of elliptic filter ",
"  eqfir   - minimax approximation of FIR filter ",
"  eqiir   - Design of iir filters ",
"  faurre   - filter ",
"  ffilt   - coefficients of FIR low-pass ",
"  fft   - fast fourier transform. ",
"  filter   - modelling filter ",
"  find_freq   - parameter compatibility for elliptic filter design ",
"  findm   - for elliptic filter design ",
"  frmag   - magnitude of FIR and IIR filters ",
"  fsfirlin   - design of FIR, linear phase filters ",
"  fwiir   - IIR filters in cascade realization ",
"  group   - group delay for digital filter ",
"  hank   - hankel matrix ",
"  hilb   - Hilbert transform ",
"  iir   - iir digital filter ",
"  iirgroup   - group delay Lp IIR filter optimization ",
"  iirlp   - Lp IIR filter optimization ",
"  intdec   - Changes  sampling rate of a signal ",
"  jmat   - row or column block permutation ",
"  kalm   - Kalman update ",
"  lattn   - recursive solution of normal equations ",
"  lattp   - lattp ",
"  lev   - Yule-Walker equations (Levinson's algorithm) ",
"  levin   - Toeplitz system solver ",
"  lgfft   - utility for fft ",
"  lindquist   - Lindquist's algorithm ",
"  mese   - maximum entropy spectral estimation ",
"  mfft   - multi-dimensional fft ",
"  phc   - from the hankel matrix to state-space model ",
"  pspect   - cross-spectral estimate between 2 series ",
"  remez   - Remez's algorithm ",
"  remezb   - Minimax approximation of magnitude response ",
"  rpem   - RPEM estimation ",
"  sinc   -  samples of sinc function ",
"  sincd   - sinc function ",
"  srfaur   - square-root algorithm ",
"  srkf   - square root Kalman filter ",
"  sskf   - steady-state Kalman filter ",
"  system   - observation update ",
"  trans   - low-pass to other filter transform ",
"  wfir   - linear-phase FIR filters ",
"  wiener   -  Wiener estimate ",
"  wigner   - 'time-frequency' wigner spectrum ",
"  window   - symmetric window ",
"  yulewalk   -  least-square filter design ",
"  zpbutt   - Butterworth analog filter ",
"  zpch1   - Chebyshev analog filter ",
"  zpch2   - Chebyshev analog filter ",
"  zpell   - lowpass elliptic filter ",
